package com.appsflyer.internal;

import android.content.Context;
import androidx.core.app.NotificationCompat;
import com.android.installreferrer.api.InstallReferrerClient;
import com.android.installreferrer.api.InstallReferrerStateListener;
import com.android.installreferrer.api.ReferrerDetails;
import com.appsflyer.AFLogger;
import com.appsflyer.internal.AFe1dSDK;
import java.util.HashMap;
import java.util.Map;
/* loaded from: classes.dex */
public class AFe1fSDK extends AFe1hSDK {
    public final Map<String, Object> AFInAppEventType;

    public AFe1fSDK(Runnable runnable) {
        super("store", "google", runnable);
        this.AFInAppEventType = new HashMap();
    }

    private static boolean AFInAppEventParameterName(Context context) {
        if (AFKeystoreWrapper(context)) {
            try {
                Class.forName("com.android.installreferrer.api.InstallReferrerClient");
                if (AFb1wSDK.valueOf(context, "com.google.android.finsky.permission.BIND_GET_INSTALL_REFERRER_SERVICE")) {
                    AFLogger.afDebugLog("Install referrer is allowed");
                    return true;
                }
                AFLogger.afDebugLog("Install referrer is not allowed");
                return false;
            } catch (ClassNotFoundException e) {
                AFLogger.afErrorLogForExcManagerOnly("InstallReferrerClient not found", e);
                StringBuilder sb = new StringBuilder("Class ");
                sb.append("com.android.installreferrer.api.InstallReferrerClient");
                sb.append(" not found");
                AFLogger.afRDLog(sb.toString());
                return false;
            } catch (Throwable th) {
                AFLogger.afErrorLog("An error occurred while trying to verify manifest : ".concat("com.android.installreferrer.api.InstallReferrerClient"), th);
                return false;
            }
        }
        return false;
    }

    @Override // com.appsflyer.internal.AFe1dSDK
    public final void AFInAppEventType(final Context context) {
        if (AFInAppEventParameterName(context)) {
            this.afDebugLog = System.currentTimeMillis();
            this.afErrorLog = AFe1dSDK.AFa1zSDK.STARTED;
            addObserver(new AFe1dSDK.AnonymousClass2());
            try {
                final InstallReferrerClient build = InstallReferrerClient.newBuilder(context).build();
                AFLogger.afDebugLog("Connecting to Install Referrer Library...");
                build.startConnection(new InstallReferrerStateListener() { // from class: com.appsflyer.internal.AFe1fSDK.2
                    @Override // com.android.installreferrer.api.InstallReferrerStateListener
                    public final void onInstallReferrerSetupFinished(int i) {
                        AFe1fSDK.this.AFInAppEventType.put("code", String.valueOf(i));
                        AFe1fSDK.this.AFKeystoreWrapper.put("api_ver", Long.valueOf(AFb1wSDK.values(context, "com.android.vending")));
                        AFe1fSDK.this.AFKeystoreWrapper.put("api_ver_name", AFb1wSDK.AFInAppEventType(context, "com.android.vending"));
                        if (i == -1) {
                            AFLogger.afWarnLog("InstallReferrer SERVICE_DISCONNECTED");
                            AFe1fSDK.this.AFKeystoreWrapper.put("response", "SERVICE_DISCONNECTED");
                        } else if (i == 0) {
                            AFe1fSDK.this.AFKeystoreWrapper.put("response", "OK");
                            try {
                                AFLogger.afDebugLog("InstallReferrer connected");
                                if (build.isReady()) {
                                    ReferrerDetails installReferrer = build.getInstallReferrer();
                                    String installReferrer2 = installReferrer.getInstallReferrer();
                                    if (installReferrer2 != null) {
                                        AFe1fSDK.this.AFInAppEventType.put("val", installReferrer2);
                                        AFe1fSDK.this.AFKeystoreWrapper.put("referrer", installReferrer2);
                                    }
                                    long referrerClickTimestampSeconds = installReferrer.getReferrerClickTimestampSeconds();
                                    AFe1fSDK.this.AFInAppEventType.put("clk", Long.toString(referrerClickTimestampSeconds));
                                    AFe1fSDK.this.AFKeystoreWrapper.put("click_ts", Long.valueOf(referrerClickTimestampSeconds));
                                    long installBeginTimestampSeconds = installReferrer.getInstallBeginTimestampSeconds();
                                    AFe1fSDK.this.AFInAppEventType.put("install", Long.toString(installBeginTimestampSeconds));
                                    AFe1fSDK.this.AFKeystoreWrapper.put("install_begin_ts", Long.valueOf(installBeginTimestampSeconds));
                                    HashMap hashMap = new HashMap();
                                    try {
                                        boolean googlePlayInstantParam = installReferrer.getGooglePlayInstantParam();
                                        AFe1fSDK.this.AFInAppEventType.put("instant", Boolean.valueOf(googlePlayInstantParam));
                                        hashMap.put("instant", Boolean.valueOf(googlePlayInstantParam));
                                    } catch (NoSuchMethodError e) {
                                        AFLogger.afErrorLogForExcManagerOnly("getGooglePlayInstantParam not exist", e);
                                    }
                                    try {
                                        hashMap.put("click_server_ts", Long.valueOf(installReferrer.getReferrerClickTimestampServerSeconds()));
                                        hashMap.put("install_begin_server_ts", Long.valueOf(installReferrer.getInstallBeginTimestampServerSeconds()));
                                        hashMap.put("install_version", installReferrer.getInstallVersion());
                                    } catch (NoSuchMethodError e2) {
                                        AFLogger.afErrorLogForExcManagerOnly("some method not exist", e2);
                                    }
                                    if (!hashMap.isEmpty()) {
                                        AFe1fSDK.this.AFKeystoreWrapper.put("google_custom", hashMap);
                                    }
                                } else {
                                    AFLogger.afWarnLog("ReferrerClient: InstallReferrer is not ready");
                                    AFe1fSDK.this.AFInAppEventType.put(NotificationCompat.CATEGORY_ERROR, "ReferrerClient: InstallReferrer is not ready");
                                }
                            } catch (Throwable th) {
                                AFLogger.afWarnLog("Failed to get install referrer: " + th.getMessage());
                                AFe1fSDK.this.AFInAppEventType.put(NotificationCompat.CATEGORY_ERROR, th.getMessage());
                                AFLogger.afErrorLogForExcManagerOnly("Failed to get install referrer", th);
                            }
                        } else if (i == 1) {
                            AFe1fSDK.this.AFKeystoreWrapper.put("response", "SERVICE_UNAVAILABLE");
                            AFLogger.afWarnLog("InstallReferrer not supported");
                        } else if (i == 2) {
                            AFLogger.afWarnLog("InstallReferrer FEATURE_NOT_SUPPORTED");
                            AFe1fSDK.this.AFKeystoreWrapper.put("response", "FEATURE_NOT_SUPPORTED");
                        } else if (i == 3) {
                            AFLogger.afWarnLog("InstallReferrer DEVELOPER_ERROR");
                            AFe1fSDK.this.AFKeystoreWrapper.put("response", "DEVELOPER_ERROR");
                        } else {
                            AFLogger.afWarnLog("responseCode not found.");
                        }
                        AFLogger.afDebugLog("Install Referrer collected locally");
                        AFe1fSDK.this.values();
                        build.endConnection();
                    }

                    @Override // com.android.installreferrer.api.InstallReferrerStateListener
                    public final void onInstallReferrerServiceDisconnected() {
                        AFLogger.afDebugLog("Install Referrer service disconnected");
                    }
                });
            } catch (Throwable th) {
                AFLogger.afErrorLog("referrerClient -> startConnection", th);
            }
        }
    }
}
