package com.appsflyer.share;

import android.content.Context;
import com.appsflyer.AFInAppEventParameterName;
import com.appsflyer.AFLogger;
import com.appsflyer.AppsFlyerLib;
import com.appsflyer.AppsFlyerProperties;
import com.appsflyer.CreateOneLinkHttpTask;
import com.appsflyer.internal.AFb1aSDK;
import com.appsflyer.internal.AFb1tSDK;
import com.appsflyer.internal.AFb1zSDK;
import com.appsflyer.internal.AFc1gSDK;
import com.appsflyer.internal.AFd1zSDK;
import com.appsflyer.internal.AFf1ySDK;
import com.appsflyer.unity.BuildConfig;
import java.util.HashMap;
import java.util.Map;
import java.util.UUID;
import kotlin.text.Typography;
/* loaded from: classes.dex */
public class LinkGenerator {
    String AFInAppEventParameterName;
    private String AFInAppEventType;
    String AFKeystoreWrapper;
    private String AFLogger;
    private String AFLogger$LogLevel;
    private final Map<String, String> AFVersionDeclaration = new HashMap();
    private String afDebugLog;
    private String afErrorLog;
    private String afInfoLog;
    private String afRDLog;
    private String afWarnLog;
    private final String valueOf;
    private String values;

    /* loaded from: classes.dex */
    public interface ResponseListener {
        void onResponse(String str);

        void onResponseError(String str);
    }

    public LinkGenerator(String str) {
        this.valueOf = str;
    }

    public LinkGenerator setBrandDomain(String str) {
        this.afWarnLog = str;
        return this;
    }

    public String getBrandDomain() {
        return this.afWarnLog;
    }

    public LinkGenerator setDeeplinkPath(String str) {
        this.afRDLog = str;
        return this;
    }

    public LinkGenerator setBaseDeeplink(String str) {
        this.AFLogger$LogLevel = str;
        return this;
    }

    public String getChannel() {
        return this.values;
    }

    public LinkGenerator setChannel(String str) {
        this.values = str;
        return this;
    }

    public LinkGenerator setReferrerCustomerId(String str) {
        this.afInfoLog = str;
        return this;
    }

    public String getMediaSource() {
        return this.valueOf;
    }

    public Map<String, String> getUserParams() {
        return new HashMap(this.AFVersionDeclaration);
    }

    public String getCampaign() {
        return this.AFInAppEventType;
    }

    public LinkGenerator setCampaign(String str) {
        this.AFInAppEventType = str;
        return this;
    }

    public LinkGenerator addParameter(String str, String str2) {
        this.AFVersionDeclaration.put(str, str2);
        return this;
    }

    public LinkGenerator addParameters(Map<String, String> map) {
        if (map != null) {
            this.AFVersionDeclaration.putAll(map);
        }
        return this;
    }

    public LinkGenerator setReferrerUID(String str) {
        this.AFLogger = str;
        return this;
    }

    public LinkGenerator setReferrerName(String str) {
        this.afErrorLog = str;
        return this;
    }

    public LinkGenerator setReferrerImageURL(String str) {
        this.afDebugLog = str;
        return this;
    }

    public LinkGenerator setBaseURL(String str, String str2, String str3) {
        if (str == null || str.length() <= 0) {
            this.AFKeystoreWrapper = String.format("https://%s/%s", String.format("%sapp.%s", AppsFlyerLib.getInstance().getHostPrefix(), AFb1zSDK.AFInAppEventType().getHostName()), str3);
        } else {
            this.AFKeystoreWrapper = String.format("https://%s/%s", (str2 == null || str2.length() < 5) ? "go.onelink.me" : "go.onelink.me", str);
        }
        return this;
    }

    private Map<String, String> valueOf() {
        HashMap hashMap = new HashMap();
        hashMap.put("pid", this.valueOf);
        String str = this.AFLogger;
        if (str != null) {
            hashMap.put("af_referrer_uid", str);
        }
        String str2 = this.values;
        if (str2 != null) {
            hashMap.put(AFInAppEventParameterName.AF_CHANNEL, str2);
        }
        String str3 = this.afInfoLog;
        if (str3 != null) {
            hashMap.put("af_referrer_customer_id", str3);
        }
        String str4 = this.AFInAppEventType;
        if (str4 != null) {
            hashMap.put("c", str4);
        }
        String str5 = this.afErrorLog;
        if (str5 != null) {
            hashMap.put("af_referrer_name", str5);
        }
        String str6 = this.afDebugLog;
        if (str6 != null) {
            hashMap.put("af_referrer_image_url", str6);
        }
        if (this.AFLogger$LogLevel != null) {
            StringBuilder sb = new StringBuilder();
            sb.append(this.AFLogger$LogLevel);
            String str7 = this.afRDLog;
            if (str7 != null) {
                String str8 = BuildConfig.FLAVOR;
                this.afRDLog = str7.replaceFirst("^[/]", BuildConfig.FLAVOR);
                if (!this.AFLogger$LogLevel.endsWith("/")) {
                    str8 = "/";
                }
                sb.append(str8);
                sb.append(this.afRDLog);
            }
            hashMap.put("af_dp", sb.toString());
        }
        for (Map.Entry<String, String> entry : this.AFVersionDeclaration.entrySet()) {
            hashMap.put(entry.getKey(), entry.getValue());
        }
        return AFb1tSDK.AFInAppEventParameterName(hashMap);
    }

    private static String AFKeystoreWrapper(Map<String, String> map) {
        StringBuilder sb = new StringBuilder();
        for (Map.Entry<String, String> entry : map.entrySet()) {
            if (sb.length() == 0) {
                sb.append('?');
            } else {
                sb.append(Typography.amp);
            }
            sb.append(entry.getKey());
            sb.append('=');
            sb.append(entry.getValue());
        }
        return sb.toString();
    }

    public String generateLink() {
        StringBuilder sb = new StringBuilder();
        String str = this.AFKeystoreWrapper;
        if (str != null && str.startsWith("http")) {
            sb.append(this.AFKeystoreWrapper);
        } else {
            sb.append(String.format(AFf1ySDK.AFInAppEventType, AppsFlyerLib.getInstance().getHostPrefix(), AFb1zSDK.AFInAppEventType().getHostName()));
        }
        if (this.AFInAppEventParameterName != null) {
            sb.append('/');
            sb.append(this.AFInAppEventParameterName);
        }
        sb.append(AFKeystoreWrapper(valueOf()));
        return sb.toString();
    }

    public void generateLink(Context context, ResponseListener responseListener) {
        String string = AppsFlyerProperties.getInstance().getString(AppsFlyerProperties.ONELINK_ID);
        String str = this.afWarnLog;
        Map<String, String> valueOf = valueOf();
        if (AppsFlyerProperties.getInstance().getBoolean(AppsFlyerProperties.AF_WAITFOR_CUSTOMERID, false)) {
            AFLogger.afInfoLog("CustomerUserId not set, generate User Invite Link is disabled", true);
            return;
        }
        AFb1zSDK.AFInAppEventType().valueOf(context);
        AFb1aSDK valueOf2 = AFb1zSDK.AFInAppEventType().valueOf();
        AFd1zSDK aFd1zSDK = new AFd1zSDK(valueOf2, UUID.randomUUID(), string, valueOf, str, responseListener);
        AFc1gSDK afDebugLog = valueOf2.afDebugLog();
        afDebugLog.valueOf.execute(new AFc1gSDK.AnonymousClass1(aFd1zSDK));
    }

    @Deprecated
    public void generateLink(Context context, final CreateOneLinkHttpTask.ResponseListener responseListener) {
        generateLink(context, new ResponseListener() { // from class: com.appsflyer.share.LinkGenerator.5
            @Override // com.appsflyer.share.LinkGenerator.ResponseListener
            public final void onResponse(String str) {
                CreateOneLinkHttpTask.ResponseListener.this.onResponse(str);
            }

            @Override // com.appsflyer.share.LinkGenerator.ResponseListener
            public final void onResponseError(String str) {
                CreateOneLinkHttpTask.ResponseListener.this.onResponseError(str);
            }
        });
    }
}
